// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `xhv` vocabulary
//!
//! This module requires `ns-xhv` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|xhv|
//! |**Namespace base IRI**|<http://www.w3.org/1999/xhtml/vocab#>|
//! |**Description**||
//! |**Is defined by**|<https://www.w3.org/2012/pyRdfa/extract?uri=https%3A%2F%2Fwww.w3.org%2F1999%2Fxhtml%2Fvocab.xhtml&format=turtle&rdfagraph=output&vocab_expansion=false&rdfa_lite=false&embedded_rdf=true&space_preserve=true&vocab_cache=true&vocab_cache_report=false&vocab_cache_refresh=false>|
//!

use crate::namespace;

namespace!(
    "http://www.w3.org/1999/xhtml/vocab#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `alert`: A message       with important, and usually time-sensitive, information. Also see       alertdialog and status.
    alert, "alert",
    /// `alertdialog`: A       type of dialog that contains an alert message, where initial focus goes       to the dialog or an element within it. Also see alert and dialog.
    alertdialog, "alertdialog",
    /// `alternate`: alternate designates alternate       versions for a resource.
    alternate, "alternate",
    /// `appendix`: appendix refers to a resource serving       as an appendix in a collection. 
    appendix, "appendix",
    /// `application`: A       region declared as a web application, as opposed to a web document.
    application, "application",
    /// `article`: A       section of a page consisting of an independent part of a document, page,       or site.
    article, "article",
    /// `banner`: banner contains the prime heading or       internal title of a page. 
    banner, "banner",
    /// `bookmark`: bookmark refers to a bookmark - a link       to a key entry point within an extended document. 
    bookmark, "bookmark",
    /// `button`: An input       that allows for user-triggered actions when clicked or pressed.
    button, "button",
    /// `chapter`: chapter refers to a resource serving       as a chapter in a collction. 
    chapter, "chapter",
    /// `checkbox`: An       checkable input that has three possible values: true, false, or     mixed.
    checkbox, "checkbox",
    /// `cite`: cite refers to a resource that defines       a citation. 
    cite, "cite",
    /// `columnheader`: A       cell containing header information for a column.
    columnheader, "columnheader",
    /// `combobox`: A       presentation of a select; usually similar to a textbox where users can       type ahead to select an option, or type to enter arbitrary text as a new       item in the list.
    combobox, "combobox",
    /// `complementary`: secondary indicates that the section       supports but is separable from the main content of resource.
    complementary, "complementary",
    /// `contentinfo`: contentinfo has meta information about       the content on the page or the page as a whole.
    contentinfo, "contentinfo",
    /// `contents`: contents refers to a resource serving       as a table of contents. 
    contents, "contents",
    /// `copyright`: copyright refers to a copyright       statement for the resource. 
    copyright, "copyright",
    /// `definition`: definition indicates the definition of       a term or concept.
    definition, "definition",
    /// `dialog`: A dialog       is an application window that is designed to interrupt the current       processing of an application in order to prompt the user to enter       information or require a response. Also see alertdialog.
    dialog, "dialog",
    /// `directory`: A list       of references to members of a group, such as a static table of     contents.
    directory, "directory",
    /// `document`: A       region containing related information that is declared as document       content, as opposed to a web application.
    document, "document",
    /// `first`: first refers the first item in a       collection (see also start and top).
    first, "first",
    /// `glossary`: glossary refers to a resource       providing a glossary of terms. 
    glossary, "glossary",
    /// `grid`: A grid       contains cells of tabular data arranged in rows and columns, like a     table.
    grid, "grid",
    /// `gridcell`: A cell       in a grid or treegrid.
    gridcell, "gridcell",
    /// `group`: A set of       user interface objects which would not be included in a page summary or       table of contents by an assistive technology.
    group, "group",
    /// `heading`: A       heading for a section of the page.
    heading, "heading",
    /// `help`: help refers to a resource offering       help. 
    help, "help",
    /// `icon`: icon refers to a resource that       represents an icon. 
    icon, "icon",
    /// `img`: A container       for a collection of elements that form an image.
    img, "img",
    /// `index`: index refers to a resource providing       an index. 
    index, "index",
    /// `itsRules`: itsRules indicates that the designated       resource is an [ITS] rule set.
    itsRules, "itsRules",
    /// `last`: last refers to the last resource in a       collection of resources. 
    last, "last",
    /// `license`: license refers to a resource that       defines the associated license. 
    license, "license",
    /// `link`: An       interactive reference to an internal or external resource.
    link, "link",
    /// `list`: A group of       non-interactive list items.
    list, "list",
    /// `listbox`: A widget       that allows the user to select one or more items from a list of     choices.
    listbox, "listbox",
    /// `listitem`: A       single item in a list, listbox, or directory.
    listitem, "listitem",
    /// `log`: A type of       live region where new information is added in meaningful order and old       information may disappear. Also see marquee.
    log, "log",
    /// `main`: main acts as the main content of the       document. 
    main, "main",
    /// `marquee`: A type       of live region where non-essential information changes frequently. Also       see log.
    marquee, "marquee",
    /// `math`: An element       that represents a mathematical expression.
    math, "math",
    /// `menu`: A type of       widget that offers a list of choices to the user.
    menu, "menu",
    /// `menubar`: A       presentation of menu that usually remains visible and is usually       presented horizontally.
    menubar, "menubar",
    /// `menuitem`: An       option in a group of choices contained by a menu or menubar.
    menuitem, "menuitem",
    /// `menuitemcheckbox`: A checkable menuitem that has three possible       values: true, false, or mixed.
    menuitemcheckbox, "menuitemcheckbox",
    /// `menuitemradio`: A       checkable menuitem in a group of menuitemradio roles, only one of which       can be checked at a time.
    menuitemradio, "menuitemradio",
    /// `meta`: meta refers to a resource that       provides metadata. 
    meta, "meta",
    /// `navigation`: navigation indicates a collection of       items suitable for navigating the document or related documents.
    navigation, "navigation",
    /// `next`: next refers to the next resource       (after the current one) in an ordered collection of resources. 
    next, "next",
    /// `note`: note indicates the content is       parenthetic or ancillary to the main content of the resource. 
    note, "note",
    /// `option`: A       selectable item in a select list.
    option, "option",
    /// `p3pv1`: p3pv1 refers to a P3P Policy Reference       File [P3P]. 
    p3pv1, "p3pv1",
    /// `presentation`: An       element whose role is presentational and does not need to be mapped to       the accessibility API.
    presentation, "presentation",
    /// `prev`: prev refers to a previous resource       (before the current one) in an ordered collection of resources. 
    prev, "prev",
    /// `progressbar`: An       element that displays the progress status for tasks that take a long     time.
    progressbar, "progressbar",
    /// `radio`: A       checkable input in a group of radio roles, only one of which can be       checked at a time.
    radio, "radio",
    /// `radiogroup`: A       group of radio buttons.
    radiogroup, "radiogroup",
    /// `region`: A large       perceivable section of a web page or document, that the author feels       should be included in a summary of page features.
    region, "region",
    /// `relrev-properties`: 
    relrev_properties, "relrev-properties",
    /// `role`: role indicates the purpose of the       resource. See the XHTML Role       Vocabulary for roles in this vocabulary space, and XHTMLROLE for information on extending the       collection of roles. 
    role, "role",
    /// `role-properties`: 
    role_properties, "role-properties",
    /// `row`: A row of       cells in a grid.
    row, "row",
    /// `rowheader`: A cell       containing header information for a row in a grid.
    rowheader, "rowheader",
    /// `search`: search indicates that the section       provides a search facility. 
    search, "search",
    /// `section`: section refers to a resource serving       as a section in a collection. 
    section, "section",
    /// `separator`: A       divider that separates and distinguishes sections of content or groups of       menuitems.
    separator, "separator",
    /// `slider`: A user       input where the user selects a value from within a given range.
    slider, "slider",
    /// `spinbutton`: A       form of range that expects a user to select from amongst discrete     choices.
    spinbutton, "spinbutton",
    /// `start`: start refers to the first resource in       a collection of resources. 
    start, "start",
    /// `status`: A       container whose content is advisory information for the user but is not       important enough to justify an alert. Also see alert.
    status, "status",
    /// `stylesheet`: stylesheet refers to a resource       serving as a stylesheet for a resource. 
    stylesheet, "stylesheet",
    /// `subsection`: subsection refers to a resource       serving as a subsection in a collection. 
    subsection, "subsection",
    /// `tab`: A header for       a tabpanel.
    tab, "tab",
    /// `tablist`: A list       of tab elements, which are references to tabpanel elements.
    tablist, "tablist",
    /// `tabpanel`: A       container for the resources associated with a tab.
    tabpanel, "tabpanel",
    /// `textbox`: Input       that allows free-form text as their value.
    textbox, "textbox",
    /// `timer`: A       numerical counter which indicates an amount of elapsed time from a start       point, or the time remaining until an end point.
    timer, "timer",
    /// `toolbar`: A       collection of commonly used function buttons represented in compact       visual form.
    toolbar, "toolbar",
    /// `tooltip`: A       contextual popup that displays a description for an element in a mouse       hover or keyboard focused state. Supplement to the normal tooltip       processing of the user agent.
    tooltip, "tooltip",
    /// `top`: top is a synonym for start. 
    top, "top",
    /// `tree`: A type of       list that may contain sub-level nested groups that can be collapsed and       expanded.
    tree, "tree",
    /// `treegrid`: A grid       whose rows can be expanded and collapsed in the same manner as for a     tree.
    treegrid, "treegrid",
    /// `treeitem`: An       option item of a tree. This is an element within a tree that may be       expanded or collapsed if it contains a sub-level group of treeitems.
    treeitem, "treeitem",
    /// `up`: up refers to a resource "above" in a       hierarchically structured set. 
    up, "up"
);
